@@ -4,15 +4,28 @@ from docgpt import main
 
 
 def test_get_target():
-    source_path = "/path/to/sample.py"
+    source_path = "/path/to/sample"
+
     assert (
         main.get_target(source_path=source_path, target=None, overwrite=False)
         == f"/path/to/sample_{main.DEFAULT_TARGET_APPEND}"
     )
 
     assert (
-        main.get_target(source_path=source_path, target=None, overwrite=False)
-        == f"/path/to/sample_{main.DEFAULT_TARGET_APPEND}"
+        main.get_target(source_path=f"{source_path}.py", target=None, overwrite=False)
+        == f"/path/to/sample_{main.DEFAULT_TARGET_APPEND}.py"
+    )
+
+    # new_target with cpp extension
+    assert (
+        main.get_target(source_path=f"{source_path}.cpp", target="new_target", overwrite=False)
+        == f"new_target.cpp"
+    )
+
+    # mixed extension (impossible case)
+    assert (
+        main.get_target(source_path=f"{source_path}.cpp", target="new_target.py", overwrite=False)
+        == f"new_target.py.cpp"
     )
 
     assert main.get_target(source_path=source_path, target=None, overwrite=True) == source_path
